(function ($, Drupal) {
  Drupal.behaviors.simpleFavsManagePage = {
    attach(context, settings) {
      once('simple-favs-manage', '#simple-favs-manage', context).forEach(() => {
        const container = document.querySelector('#simple-favs-manage');
        const list = container.querySelector('.simple-favs-list');
        let favs = settings.simple_favs.manage?.favs || [];
        const langcode = settings.simple_favs.manage?.langcode || 'en';

        function render() {
          list.innerHTML = '';

          favs.forEach((fav, index) => {
            const li = document.createElement('li');

            const input = document.createElement('input');
            input.type = 'text';
            input.value = fav.title;
            input.className = 'form-control';
            input.disabled = true;

            input.addEventListener('focus', () => {
              input.disabled = false;
            });

            input.addEventListener('blur', () => {
              input.disabled = true;
              favs[index].title = input.value;
              settings.simple_favs.manage.favs = favs;
              save();
            });

            const link = document.createElement('a');
            link.href = fav.path;
            link.innerText = fav.path;
            link.style.marginRight = '10px';

            const btn = document.createElement('button');
            btn.className = 'btn btn-danger btn-sm';
            btn.innerText = Drupal.t('Delete');
            btn.addEventListener('click', () => {
              // Remove the item from the favs array.
              favs.splice(index, 1);
              settings.simple_favs.manage.favs = favs;
              save();
            });

            li.appendChild(input);
            li.appendChild(document.createTextNode(' '));
            li.appendChild(link);
            li.appendChild(btn);
            list.appendChild(li);
          });
        }

        function save() {
          list.querySelectorAll('input').forEach(input => input.disabled = true);

          fetch('/simple-favs/save-titles', {
            method: 'POST',
            headers: {
              'Content-Type': 'application/json',
            },
            body: JSON.stringify({ favourites: favs })
          }).then(() => {
            render();
          });
        }

        render();
      });
    }
  };
})(jQuery, Drupal);

